@@ -172,7 +172,7 @@ class TestCreatePort(TestPort):
         )
         self.assertFalse(self.network_client.set_tags.called)
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_full_options(self):
@@ -245,7 +245,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_invalid_json_binding_profile(self):
@@ -309,7 +309,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_security_group(self):
@@ -347,7 +347,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_port_with_dns_name(self):
@@ -380,7 +380,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_security_groups(self):
@@ -420,7 +420,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_no_security_groups(self):
@@ -449,7 +449,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_no_fixed_ips(self):
@@ -478,7 +478,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_port_with_allowed_address_pair_ipaddr(self):
@@ -520,7 +520,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_port_with_allowed_address_pair(self):
@@ -571,7 +571,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_port_with_qos(self):
@@ -608,7 +608,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_port_security_enabled(self):
@@ -738,7 +738,7 @@ class TestCreatePort(TestPort):
             else:
                 self.assertFalse(self.network_client.set_tags.called)
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
@@ -787,7 +787,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_uplink_status_propagation_enabled(self):
@@ -893,7 +893,7 @@ class TestCreatePort(TestPort):
             create_args['numa_affinity_policy'] = numa_affinity_policy
         self.network_client.create_port.assert_called_once_with(**create_args)
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_with_numa_affinity_policy_required(self):
@@ -940,7 +940,7 @@ class TestCreatePort(TestPort):
             'device_profile': 'cyborg_device_profile_1',
         }
         self.network_client.create_port.assert_called_once_with(**create_args)
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_hints_invalid_json(self):
@@ -1032,7 +1032,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
     def test_create_hints_valid_json(self):
@@ -1067,7 +1067,7 @@ class TestCreatePort(TestPort):
             }
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
 
@@ -1200,8 +1200,6 @@ class TestListPort(TestPort):
     def setUp(self):
         super(TestListPort, self).setUp()
 
-        # Get the command object to test
-        self.cmd = port.ListPort(self.app, self.namespace)
         self.network_client.ports = mock.Mock(return_value=self._ports)
         fake_router = network_fakes.FakeRouter.create_one_router(
             {
@@ -1215,7 +1213,12 @@ class TestListPort(TestPort):
         )
         self.network_client.find_router = mock.Mock(return_value=fake_router)
         self.network_client.find_network = mock.Mock(return_value=fake_network)
+
         self.app.client_manager.compute = mock.Mock()
+        self.compute_client = self.app.client_manager.compute
+
+        # Get the command object to test
+        self.cmd = port.ListPort(self.app, self.namespace)
 
     def test_port_list_no_options(self):
         arglist = []
@@ -1662,7 +1665,7 @@ class TestListPort(TestPort):
 
         columns, data = self.cmd.take_action(parsed_args)
         filters = {
-            'security_groups': ['sg-id1', 'sg-id2'],
+            'security_group_ids': ['sg-id1', 'sg-id2'],
             'fields': LIST_FIELDS_TO_RETRIEVE,
         }
 
@@ -2496,7 +2499,7 @@ class TestShowPort(TestPort):
             self._port.name, ignore_missing=False
         )
 
-        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
 
